;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "format-all" "20241126.829"
  "Auto-format C, C++, JS, Python, Ruby and 50 other languages."
  '((emacs       "24.4")
    (inheritenv  "0.1")
    (language-id "0.20"))
  :url "https://github.com/lassik/emacs-format-all-the-code"
  :commit "fd9c013f5f8094fef99ddabde07d9041737b8454"
  :revdesc "fd9c013f5f80"
  :keywords '("languages" "util")
  :authors '(("Lassi Kortela" . "lassi@lassi.io"))
  :maintainers '(("Lassi Kortela" . "lassi@lassi.io")))
